Context module for locker management operations.
Summary
Functions
Assign a locker to a visitor. Automatically picks the first available locker if no locker_id given.
Count lockers by status for a node.
Count lockers by status for a location.
Create a new locker.
Delete a locker. Only allowed if no active sessions.
Get the active session for a specific locker.
Get the active session for a visitor (if any) in a node.
Get location config for a specific location, returns nil if not found.
Get a single locker by id.
Get a locker by node_id and locker_number.
Get node config for a specific node, returns nil if not found.
Get a session by id with locker preloaded.
List all active sessions for a node.
List active sessions for a node with pagination.
List all active sessions for a location (non-paginated).
List active sessions for a location with pagination.
Get available lockers for a node.
Get available lockers for a location.
List all location configs for a node.
List all lockers for a node.
List lockers for a node filtered by status.
List all lockers for a location.
List all node configs.
List session history for a node with optional date filter.
List session history for a node with optional date filter and pagination.
List session history for a location with optional date filter and pagination.
Check if a location has locker system enabled.
Check if a node has locker system enabled.
Release a locker session.
Release a visitor's active locker session in a node.
Bulk-create lockers for a specific location. Locker numbers are padded integers: "001", "002", ... Only creates lockers that don't already exist for that location.
Bulk-create lockers for a node based on total count. Locker numbers are generated as padded integers: "001", "002", ... Only creates lockers that don't already exist.
Update a locker.
Create or update location config.
Create or update node config.
Functions
Assign a locker to a visitor. Automatically picks the first available locker if no locker_id given.
Count lockers by status for a node.
Count lockers by status for a location.
Create a new locker.
Delete a locker. Only allowed if no active sessions.
Get the active session for a specific locker.
Get the active session for a visitor (if any) in a node.
Get location config for a specific location, returns nil if not found.
Get a single locker by id.
Get a locker by node_id and locker_number.
Get node config for a specific node, returns nil if not found.
Get a session by id with locker preloaded.
List all active sessions for a node.
List active sessions for a node with pagination.
List all active sessions for a location (non-paginated).
List active sessions for a location with pagination.
Get available lockers for a node.
Get available lockers for a location.
List all location configs for a node.
List all lockers for a node.
List lockers for a node filtered by status.
List all lockers for a location.
List all node configs.
List session history for a node with optional date filter.
List session history for a node with optional date filter and pagination.
List session history for a location with optional date filter and pagination.
Check if a location has locker system enabled.
Check if a node has locker system enabled.
Release a locker session.
Release a visitor's active locker session in a node.
Bulk-create lockers for a specific location. Locker numbers are padded integers: "001", "002", ... Only creates lockers that don't already exist for that location.
Bulk-create lockers for a node based on total count. Locker numbers are generated as padded integers: "001", "002", ... Only creates lockers that don't already exist.
Update a locker.
Create or update location config.
Create or update node config.